# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tflite

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class StablehloTransposeOptions(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = StablehloTransposeOptions()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsStablehloTransposeOptions(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    @classmethod
    def StablehloTransposeOptionsBufferHasIdentifier(cls, buf, offset, size_prefixed=False):
        return flatbuffers.util.BufferHasIdentifier(buf, offset, b"\x54\x46\x4C\x33", size_prefixed=size_prefixed)

    # StablehloTransposeOptions
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # StablehloTransposeOptions
    def Permutation(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Int64Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 8))
        return 0

    # StablehloTransposeOptions
    def PermutationAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Int64Flags, o)
        return 0

    # StablehloTransposeOptions
    def PermutationLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # StablehloTransposeOptions
    def PermutationIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        return o == 0

def StablehloTransposeOptionsStart(builder):
    builder.StartObject(1)

def Start(builder):
    StablehloTransposeOptionsStart(builder)

def StablehloTransposeOptionsAddPermutation(builder, permutation):
    builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(permutation), 0)

def AddPermutation(builder, permutation):
    StablehloTransposeOptionsAddPermutation(builder, permutation)

def StablehloTransposeOptionsStartPermutationVector(builder, numElems):
    return builder.StartVector(8, numElems, 8)

def StartPermutationVector(builder, numElems):
    return StablehloTransposeOptionsStartPermutationVector(builder, numElems)

def StablehloTransposeOptionsEnd(builder):
    return builder.EndObject()

def End(builder):
    return StablehloTransposeOptionsEnd(builder)
