# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tflite

class StablehloComparisonDirection(object):
    STABLEHLO_COMPARISON_DIRECTION_EQ = 0
    STABLEHLO_COMPARISON_DIRECTION_NE = 1
    STABLEHLO_COMPARISON_DIRECTION_GE = 2
    STABLEHLO_COMPARISON_DIRECTION_GT = 3
    STABLEHLO_COMPARISON_DIRECTION_LE = 4
    STABLEHLO_COMPARISON_DIRECTION_LT = 5
