# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tflite

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class StablehloScatterOptions(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = StablehloScatterOptions()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsStablehloScatterOptions(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    @classmethod
    def StablehloScatterOptionsBufferHasIdentifier(cls, buf, offset, size_prefixed=False):
        return flatbuffers.util.BufferHasIdentifier(buf, offset, b"\x54\x46\x4C\x33", size_prefixed=size_prefixed)

    # StablehloScatterOptions
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # StablehloScatterOptions
    def IndicesAreSorted(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return bool(self._tab.Get(flatbuffers.number_types.BoolFlags, o + self._tab.Pos))
        return False

    # StablehloScatterOptions
    def UpdateWindowDims(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Int64Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 8))
        return 0

    # StablehloScatterOptions
    def UpdateWindowDimsAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Int64Flags, o)
        return 0

    # StablehloScatterOptions
    def UpdateWindowDimsLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # StablehloScatterOptions
    def UpdateWindowDimsIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        return o == 0

    # StablehloScatterOptions
    def InsertedWindowDims(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Int64Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 8))
        return 0

    # StablehloScatterOptions
    def InsertedWindowDimsAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Int64Flags, o)
        return 0

    # StablehloScatterOptions
    def InsertedWindowDimsLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # StablehloScatterOptions
    def InsertedWindowDimsIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        return o == 0

    # StablehloScatterOptions
    def ScatterDimsToOperandDims(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Int64Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 8))
        return 0

    # StablehloScatterOptions
    def ScatterDimsToOperandDimsAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Int64Flags, o)
        return 0

    # StablehloScatterOptions
    def ScatterDimsToOperandDimsLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # StablehloScatterOptions
    def ScatterDimsToOperandDimsIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        return o == 0

    # StablehloScatterOptions
    def IndexVectorDim(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # StablehloScatterOptions
    def UniqueIndices(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return bool(self._tab.Get(flatbuffers.number_types.BoolFlags, o + self._tab.Pos))
        return False

    # StablehloScatterOptions
    def UpdateComputationSubgraphIndex(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

def StablehloScatterOptionsStart(builder):
    builder.StartObject(7)

def Start(builder):
    StablehloScatterOptionsStart(builder)

def StablehloScatterOptionsAddIndicesAreSorted(builder, indicesAreSorted):
    builder.PrependBoolSlot(0, indicesAreSorted, 0)

def AddIndicesAreSorted(builder, indicesAreSorted):
    StablehloScatterOptionsAddIndicesAreSorted(builder, indicesAreSorted)

def StablehloScatterOptionsAddUpdateWindowDims(builder, updateWindowDims):
    builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(updateWindowDims), 0)

def AddUpdateWindowDims(builder, updateWindowDims):
    StablehloScatterOptionsAddUpdateWindowDims(builder, updateWindowDims)

def StablehloScatterOptionsStartUpdateWindowDimsVector(builder, numElems):
    return builder.StartVector(8, numElems, 8)

def StartUpdateWindowDimsVector(builder, numElems):
    return StablehloScatterOptionsStartUpdateWindowDimsVector(builder, numElems)

def StablehloScatterOptionsAddInsertedWindowDims(builder, insertedWindowDims):
    builder.PrependUOffsetTRelativeSlot(2, flatbuffers.number_types.UOffsetTFlags.py_type(insertedWindowDims), 0)

def AddInsertedWindowDims(builder, insertedWindowDims):
    StablehloScatterOptionsAddInsertedWindowDims(builder, insertedWindowDims)

def StablehloScatterOptionsStartInsertedWindowDimsVector(builder, numElems):
    return builder.StartVector(8, numElems, 8)

def StartInsertedWindowDimsVector(builder, numElems):
    return StablehloScatterOptionsStartInsertedWindowDimsVector(builder, numElems)

def StablehloScatterOptionsAddScatterDimsToOperandDims(builder, scatterDimsToOperandDims):
    builder.PrependUOffsetTRelativeSlot(3, flatbuffers.number_types.UOffsetTFlags.py_type(scatterDimsToOperandDims), 0)

def AddScatterDimsToOperandDims(builder, scatterDimsToOperandDims):
    StablehloScatterOptionsAddScatterDimsToOperandDims(builder, scatterDimsToOperandDims)

def StablehloScatterOptionsStartScatterDimsToOperandDimsVector(builder, numElems):
    return builder.StartVector(8, numElems, 8)

def StartScatterDimsToOperandDimsVector(builder, numElems):
    return StablehloScatterOptionsStartScatterDimsToOperandDimsVector(builder, numElems)

def StablehloScatterOptionsAddIndexVectorDim(builder, indexVectorDim):
    builder.PrependInt64Slot(4, indexVectorDim, 0)

def AddIndexVectorDim(builder, indexVectorDim):
    StablehloScatterOptionsAddIndexVectorDim(builder, indexVectorDim)

def StablehloScatterOptionsAddUniqueIndices(builder, uniqueIndices):
    builder.PrependBoolSlot(5, uniqueIndices, 0)

def AddUniqueIndices(builder, uniqueIndices):
    StablehloScatterOptionsAddUniqueIndices(builder, uniqueIndices)

def StablehloScatterOptionsAddUpdateComputationSubgraphIndex(builder, updateComputationSubgraphIndex):
    builder.PrependInt32Slot(6, updateComputationSubgraphIndex, 0)

def AddUpdateComputationSubgraphIndex(builder, updateComputationSubgraphIndex):
    StablehloScatterOptionsAddUpdateComputationSubgraphIndex(builder, updateComputationSubgraphIndex)

def StablehloScatterOptionsEnd(builder):
    return builder.EndObject()

def End(builder):
    return StablehloScatterOptionsEnd(builder)
