# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tflite

class ReduceWindowFunction(object):
    UNSUPPORTED = 0
    ADD = 1
    MUL = 2
    MINIMUM = 3
    MAXIMUM = 4
    ALL = 5
    ANY = 6
