# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tflite

class StablehloComparisonType(object):
    STABLEHLO_COMPARISON_TYPE_NOTYPE = 0
    STABLEHLO_COMPARISON_TYPE_FLOAT = 1
    STABLEHLO_COMPARISON_TYPE_FLOAT_TOTAL_ORDER = 2
    STABLEHLO_COMPARISON_TYPE_SIGNED = 3
    STABLEHLO_COMPARISON_TYPE_UNSIGNED = 4
