# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tflite

class BuiltinOptions2(object):
    NONE = 0
    StablehloConcatenateOptions = 1
    StablehloBroadcastInDimOptions = 2
    StablehloSliceOptions = 3
    StablehloConvolutionOptions = 4
    StablehloCustomCallOptions = 5
    StablehloReduceOptions = 6
    StablehloScatterOptions = 7
    StablehloCompareOptions = 8
    StablehloDynamicSliceOptions = 9
    StablehloPadOptions = 10
    StablehloIotaOptions = 11
    StablehloDotGeneralOptions = 12
    StablehloReduceWindowOptions = 13
    StablehloSortOptions = 14
    StablehloWhileOptions = 15
    StablehloGatherOptions = 16
    StablehloTransposeOptions = 17
    DilateOptions = 18
    StablehloRngBitGeneratorOptions = 19
    ReduceWindowOptions = 20
    StableHLOCompositeOptions = 21
    StablehloShiftLeftOptions = 22
